from omni.pro.models.base import BaseModel
from omni.pro.models.sql.catalog.category import Category
from omni.pro.protos.v1.rules.delivery_category_pb2 import DeliveryCategory as DeliveryCategoryProto
from peewee import CharField, DeferredThroughModel, ManyToManyField


class DeliveryCategory(BaseModel):
    name = CharField()
    categ_ids = ManyToManyField(Category, backref="delivery_category_ids", through_model=DeferredThroughModel())

    class Meta:
        table_name = "delivery_category"

    def to_proto(self):
        return DeliveryCategoryProto(
            id=self.id,
            name=self.name,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from peewee import CharField

from omni.pro.models.base import BaseModel
from omni.pro.protos.common.country_pb2 import Country as CountryProto


class Country(BaseModel):
    country_doc_id = CharField()
    name = CharField(max_length=100)
    code = CharField(unique=True)

    class Meta:
        table_name = "country"

    def to_proto(self) -> CountryProto:
        return CountryProto(
            id=self.id,
            country_doc_id=self.country_doc_id,
            name=self.name,
            code=self.code,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_schedule_warehouse_hierarchy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n4v1/rules/delivery_schedule_warehouse_hierarchy.proto\x12?pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy\x1a\x11\x63ommon/base.proto"\xbf\x01\n"DeliveryScheduleWarehouseHierarchy\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\x14\x64\x65livery_schedule_id\x18\x02 \x01(\x05\x12\x1e\n\x16warehouse_hierarchy_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa7\x01\n/DeliveryScheduleWarehouseHierarchyCreateRequest\x12\x1c\n\x14\x64\x65livery_schedule_id\x18\x01 \x01(\x05\x12\x1e\n\x16warehouse_hierarchy_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x92\x02\n0DeliveryScheduleWarehouseHierarchyCreateResponse\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x03\n-DeliveryScheduleWarehouseHierarchyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcb\x02\n.DeliveryScheduleWarehouseHierarchyReadResponse\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x03(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfe\x01\n/DeliveryScheduleWarehouseHierarchyUpdateRequest\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x92\x02\n0DeliveryScheduleWarehouseHierarchyUpdateResponse\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"u\n/DeliveryScheduleWarehouseHierarchyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"}\n0DeliveryScheduleWarehouseHierarchyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf5\x08\n)DeliveryScheduleWarehouseHierarchyService\x12\x91\x02\n(DeliveryScheduleWarehouseHierarchyCreate\x12p.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyCreateRequest\x1aq.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyCreateResponse"\x00\x12\x8b\x02\n&DeliveryScheduleWarehouseHierarchyRead\x12n.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyReadRequest\x1ao.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyReadResponse"\x00\x12\x91\x02\n(DeliveryScheduleWarehouseHierarchyUpdate\x12p.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyUpdateRequest\x1aq.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyUpdateResponse"\x00\x12\x91\x02\n(DeliveryScheduleWarehouseHierarchyDelete\x12p.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyDeleteRequest\x1aq.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_schedule_warehouse_hierarchy_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHY"]._serialized_start = 141
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHY"]._serialized_end = 332
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_start = 335
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_end = 502
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_start = 505
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_end = 779
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADREQUEST"]._serialized_start = 782
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADREQUEST"]._serialized_end = 1177
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADRESPONSE"]._serialized_start = 1180
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADRESPONSE"]._serialized_end = 1511
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_start = 1514
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_end = 1768
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_start = 1771
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_end = 2045
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_start = 2047
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_end = 2164
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_start = 2166
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_end = 2291
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYSERVICE"]._serialized_start = 2294
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYSERVICE"]._serialized_end = 3435
# @@protoc_insertion_point(module_scope)



from omni.pro.models.base import BaseModel
from omni.pro.models.stock.warehouse import Warehouse
from omni.pro.protos.v1.stock.stock_pb2 import Location as LocationProto
from peewee import BooleanField, CharField, ForeignKeyField


class Location(BaseModel):
    name = CharField()
    code = CharField()
    parent_id = ForeignKeyField("self", backref="children", null=True)
    type_location = CharField()
    barcode = CharField()
    warehouse_id = ForeignKeyField(Warehouse, backref="locations")
    active = BooleanField()

    class Meta:
        table_name = "location"

    def to_proto(self):
        parent_id = self.parent_id.id if self.parent_id else None
        return LocationProto(
            id=self.id,
            name=self.name,
            code=self.code,
            parent_id=parent_id,
            type_location=self.type_location,
            barcode=self.barcode,
            warehouse_id=self.warehouse_id.id,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from omni.pro.models.base import BaseModel
from peewee import CharField


class Country(BaseModel):
    country_doc_id = CharField()
    name = CharField()
    code = CharField()

    class Meta:
        table_name = "country"



from google.protobuf import struct_pb2
from peewee import CharField, ForeignKeyField
from playhouse.postgres_ext import JSONField

from omni.pro.models.base import BaseModel
from omni.pro.models.sql.utilities.country import Country
from omni.pro.protos.v1.stock.stock_pb2 import Warehouse as WarehouseProto


class Warehouse(BaseModel):
    name = CharField()
    code = CharField(unique=True)
    country_id = ForeignKeyField(Country, backref="warehouses", on_delete="RESTRICT")
    territory_matrix_value = JSONField()
    address = CharField()
    complement = CharField()

    class Meta:
        table_name = "warehouse"

    def struct_to_proto(self, data: dict) -> struct_pb2.Struct:
        """
        struct_to_proto [converts a python dict to a google protobuf struct]

        Parameters
        ----------
        struct : dict
            python dict

        Returns
        -------
        struct_pb2.Struct
            Google protobuf struct
        """
        struct = struct_pb2.Struct()
        if data:
            struct.update(data)
        return struct

    def to_proto(self) -> WarehouseProto:
        warehouse_proto = WarehouseProto(
            object_audit=self.get_audit_proto(),
            id=self.id,
            name=self.name,
            code=self.code,
            country_id=self.country_id.id,
            territory_matrix_value=self.struct_to_proto(self.territory_matrix_value),
            address=self.address,
            complement=self.complement,
            active=self.active,
        )
        return warehouse_proto



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_category_category_pb2 as v1_dot_rules_dot_delivery__category__category__pb2,
)


class DeliveryCategoryCategoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryCategoryCategoryCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryCreate",
            request_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryCreateResponse.FromString,
        )
        self.DeliveryCategoryCategoryRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryRead",
            request_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryReadResponse.FromString,
        )
        self.DeliveryCategoryCategoryUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryUpdate",
            request_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryUpdateResponse.FromString,
        )
        self.DeliveryCategoryCategoryDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryDelete",
            request_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryDeleteResponse.FromString,
        )


class DeliveryCategoryCategoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryCategoryCategoryCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryCategoryRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryCategoryUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryCategoryDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryCategoryCategoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryCategoryCategoryCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryCategoryCreate,
            request_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryCreateResponse.SerializeToString,
        ),
        "DeliveryCategoryCategoryRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryCategoryRead,
            request_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryReadResponse.SerializeToString,
        ),
        "DeliveryCategoryCategoryUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryCategoryUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryUpdateResponse.SerializeToString,
        ),
        "DeliveryCategoryCategoryDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryCategoryDelete,
            request_deserializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryCategoryCategoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryCategoryCategoryCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryCreate",
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryCategoryRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryRead",
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryCategoryUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryUpdate",
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryCategoryDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryService/DeliveryCategoryCategoryDelete",
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__category__pb2.DeliveryCategoryCategoryDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.rules.calendar_pb2 import Calendar as CalendarProto
from peewee import CharField


class Calendar(BaseModel):
    name = CharField()

    class Meta:
        table_name = "calendar"

    def to_proto(self):
        return CalendarProto(
            id=self.id,
            name=self.name,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from peewee import CharField

from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.stock.picking_pb2 import ProcurementGroup as ProcurementGroupProto


class ProcurementGroup(BaseModel):
    name = CharField()
    move_type = CharField()

    class Meta:
        table_name = "procurement_group"

    def to_proto(self):
        return ProcurementGroupProto(
            id=self.id,
            name=self.name,
            move_type=self.move_type,
            object_audit=self.get_audit_proto(),
            active=self.active,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_schedule_warehouse_hierarchy_pb2 as v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2,
)


class DeliveryScheduleWarehouseHierarchyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryScheduleWarehouseHierarchyCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyCreate",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateResponse.FromString,
        )
        self.DeliveryScheduleWarehouseHierarchyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyRead",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadResponse.FromString,
        )
        self.DeliveryScheduleWarehouseHierarchyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyUpdate",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateResponse.FromString,
        )
        self.DeliveryScheduleWarehouseHierarchyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyDelete",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteResponse.FromString,
        )


class DeliveryScheduleWarehouseHierarchyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryScheduleWarehouseHierarchyCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleWarehouseHierarchyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleWarehouseHierarchyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleWarehouseHierarchyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryScheduleWarehouseHierarchyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryScheduleWarehouseHierarchyCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyCreate,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateResponse.SerializeToString,
        ),
        "DeliveryScheduleWarehouseHierarchyRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyRead,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadResponse.SerializeToString,
        ),
        "DeliveryScheduleWarehouseHierarchyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateResponse.SerializeToString,
        ),
        "DeliveryScheduleWarehouseHierarchyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyDelete,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryScheduleWarehouseHierarchyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyCreate",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyRead",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyUpdate",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyDelete",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from omni.pro.models.base import BaseModel
from omni.pro.models.sql.rules.delivery_locality import DeliveryLocality
from omni.pro.models.sql.utilities.territory_matrix_values import TerritoryMatrixValues
from omni.pro.protos.v1.rules.delivery_locality_matrix_values_pb2 import (
    DeliveryLocalityMatrixValues as DeliveryLocalityMatrixValuesProto,
)
from peewee import DeferredThroughModel, ForeignKeyField


# TODO tabla intermedia entre delivery_locality y territory_matrix_values
class DeliveryLocalityTerritoryMatrixValues(BaseModel):
    delivery_locality_id = ForeignKeyField(DeliveryLocality, on_delete="RESTRICT")
    territory_matrix_values_id = ForeignKeyField(TerritoryMatrixValues, on_delete="RESTRICT")

    def to_proto(self):
        return DeliveryLocalityMatrixValuesProto(
            id=self.id,
            delivery_locality_id=self.delivery_locality_id.id,
            territory_matrix_values_id=self.territory_matrix_values_id,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )

    class Meta:
        table_name = "delivery_locality_territory_matrix_values"


DeferredThroughModel.set_model(DeliveryLocality.territory_matrix_values_ids, DeliveryLocalityTerritoryMatrixValues)



from google.protobuf.timestamp_pb2 import Timestamp
from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.rules.schedule_work_line_pb2 import ScheduleWorkLine as ScheduleWorkLineProto
from peewee import CharField, DateTimeField


class ScheduleWorkLine(BaseModel):
    DAY = (
        (0, "monday"),
        (1, "tuesday"),
        (2, "wednesday"),
        (3, "thursday"),
        (4, "friday"),
        (5, "saturday"),
        (6, "sunday"),
    )
    day = CharField(choices=DAY)
    opening_time = DateTimeField()
    closing_time = DateTimeField()

    class Meta:
        table_name = "schedule_work_line"

    def to_proto(self):
        opening_time = Timestamp()
        opening_time.FromDatetime(self.opening_time)
        closing_time = Timestamp()
        closing_time.FromDatetime(self.closing_time)

        return ScheduleWorkLineProto(
            id=self.id,
            day=self.day,
            opening_time=opening_time,
            closing_time=closing_time,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from omni.pro.models.base import BaseModel
from omni.pro.models.sql.rules.schedule_work import ScheduleWork
from omni.pro.models.sql.rules.warehouse_hierarchy import WarehouseHierarchy
from omni.pro.protos.v1.rules.delivery_schedule_pb2 import DeliverySchedule as DeliveryScheduleProto
from omni.pro.protos.v1.rules.delivery_schedule_warehouse_hierarchy_pb2 import (
    DeliveryScheduleWarehouseHierarchy as DeliveryScheduleWarehouseHierarchyProto,
)
from peewee import CharField, DeferredThroughModel, ForeignKeyField, ManyToManyField


class DeliverySchedule(BaseModel):
    name = CharField()
    schedule_work_id = ForeignKeyField(ScheduleWork, on_delete="RESTRICT")
    transfer_warehouse_ids = ManyToManyField(
        WarehouseHierarchy, backref="transfer_warehouse_ids", through_model=DeferredThroughModel()
    )

    def to_proto(self):
        return DeliveryScheduleProto(
            id=self.id,
            name=self.name,
            schedule_work_id=self.schedule_work_id.id,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/picking_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/stock/picking_type.proto\x12&pro.omni.oms.api.v1.stock.picking.type\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf1\x03\n\x0bPickingType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rsequence_code\x18\x03 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x04 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x06 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\t \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\n \x01(\x05\x12\x0e\n\x06prefix\x18\x0b \x01(\t\x12\x0f\n\x07padding\x18\x0c \x01(\x05\x12\x18\n\x10number_increment\x18\r \x01(\x05\x12\x1a\n\x12number_next_actual\x18\x0e \x01(\x05\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x10 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xbd\x03\n\x18PickingTypeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rsequence_code\x18\x02 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x05 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\x08 \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\t \x01(\x05\x12\x0e\n\x06prefix\x18\n \x01(\t\x12\x0f\n\x07padding\x18\x0b \x01(\x05\x12\x18\n\x10number_increment\x18\x0c \x01(\x05\x12\x1a\n\x12number_next_actual\x18\r \x01(\x05\x12\x36\n\x07\x63ontext\x18\x0e \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb1\x01\n\x19PickingTypeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12I\n\x0cpicking_type\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.type.PickingType"\xf4\x02\n\x16PickingTypeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xeb\x01\n\x17PickingTypeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12J\n\rpicking_types\x18\x03 \x03(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.type.PickingType"\x9d\x01\n\x18PickingTypeUpdateRequest\x12I\n\x0cpicking_type\x18\x01 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.type.PickingType\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb1\x01\n\x19PickingTypeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12I\n\x0cpicking_type\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking.type.PickingType"^\n\x18PickingTypeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"f\n\x19PickingTypeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x82\x05\n\x12PickingTypeService\x12\x9a\x01\n\x11PickingTypeCreate\x12@.pro.omni.oms.api.v1.stock.picking.type.PickingTypeCreateRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking.type.PickingTypeCreateResponse"\x00\x12\x94\x01\n\x0fPickingTypeRead\x12>.pro.omni.oms.api.v1.stock.picking.type.PickingTypeReadRequest\x1a?.pro.omni.oms.api.v1.stock.picking.type.PickingTypeReadResponse"\x00\x12\x9a\x01\n\x11PickingTypeUpdate\x12@.pro.omni.oms.api.v1.stock.picking.type.PickingTypeUpdateRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking.type.PickingTypeUpdateResponse"\x00\x12\x9a\x01\n\x11PickingTypeDelete\x12@.pro.omni.oms.api.v1.stock.picking.type.PickingTypeDeleteRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking.type.PickingTypeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.picking_type_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PICKINGTYPE"]._serialized_start = 153
    _globals["_PICKINGTYPE"]._serialized_end = 650
    _globals["_PICKINGTYPECREATEREQUEST"]._serialized_start = 653
    _globals["_PICKINGTYPECREATEREQUEST"]._serialized_end = 1098
    _globals["_PICKINGTYPECREATERESPONSE"]._serialized_start = 1101
    _globals["_PICKINGTYPECREATERESPONSE"]._serialized_end = 1278
    _globals["_PICKINGTYPEREADREQUEST"]._serialized_start = 1281
    _globals["_PICKINGTYPEREADREQUEST"]._serialized_end = 1653
    _globals["_PICKINGTYPEREADRESPONSE"]._serialized_start = 1656
    _globals["_PICKINGTYPEREADRESPONSE"]._serialized_end = 1891
    _globals["_PICKINGTYPEUPDATEREQUEST"]._serialized_start = 1894
    _globals["_PICKINGTYPEUPDATEREQUEST"]._serialized_end = 2051
    _globals["_PICKINGTYPEUPDATERESPONSE"]._serialized_start = 2054
    _globals["_PICKINGTYPEUPDATERESPONSE"]._serialized_end = 2231
    _globals["_PICKINGTYPEDELETEREQUEST"]._serialized_start = 2233
    _globals["_PICKINGTYPEDELETEREQUEST"]._serialized_end = 2327
    _globals["_PICKINGTYPEDELETERESPONSE"]._serialized_start = 2329
    _globals["_PICKINGTYPEDELETERESPONSE"]._serialized_end = 2431
    _globals["_PICKINGTYPESERVICE"]._serialized_start = 2434
    _globals["_PICKINGTYPESERVICE"]._serialized_end = 3076
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    schedule_work_schedule_work_line_pb2 as v1_dot_rules_dot_schedule__work__schedule__work__line__pb2,
)


class ScheduleWorkScheduleWorkLineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ScheduleWorkScheduleWorkLineCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineCreate",
            request_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineCreateResponse.FromString,
        )
        self.ScheduleWorkScheduleWorkLineRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineRead",
            request_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineReadResponse.FromString,
        )
        self.ScheduleWorkScheduleWorkLineUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineUpdate",
            request_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineUpdateResponse.FromString,
        )
        self.ScheduleWorkScheduleWorkLineDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineDelete",
            request_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineDeleteResponse.FromString,
        )


class ScheduleWorkScheduleWorkLineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ScheduleWorkScheduleWorkLineCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkScheduleWorkLineRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkScheduleWorkLineUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleWorkScheduleWorkLineDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ScheduleWorkScheduleWorkLineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ScheduleWorkScheduleWorkLineCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkScheduleWorkLineCreate,
            request_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineCreateResponse.SerializeToString,
        ),
        "ScheduleWorkScheduleWorkLineRead": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkScheduleWorkLineRead,
            request_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineReadResponse.SerializeToString,
        ),
        "ScheduleWorkScheduleWorkLineUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkScheduleWorkLineUpdate,
            request_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineUpdateResponse.SerializeToString,
        ),
        "ScheduleWorkScheduleWorkLineDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleWorkScheduleWorkLineDelete,
            request_deserializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ScheduleWorkScheduleWorkLineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ScheduleWorkScheduleWorkLineCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineCreate",
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineCreateRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkScheduleWorkLineRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineRead",
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineReadRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkScheduleWorkLineUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineUpdate",
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineUpdateRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleWorkScheduleWorkLineDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineService/ScheduleWorkScheduleWorkLineDelete",
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineDeleteRequest.SerializeToString,
            v1_dot_rules_dot_schedule__work__schedule__work__line__pb2.ScheduleWorkScheduleWorkLineDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from omni.pro.models.base import BaseModel
from omni.pro.models.sql.rules.delivery_schedule import DeliverySchedule
from omni.pro.models.sql.rules.warehouse_hierarchy import WarehouseHierarchy
from omni.pro.protos.v1.rules.delivery_schedule_warehouse_hierarchy_pb2 import (
    DeliveryScheduleWarehouseHierarchy as DeliveryScheduleWarehouseHierarchyProto,
)
from peewee import CharField, DeferredThroughModel, ForeignKeyField, ManyToManyField


# TODO tabla intermedia entre delivery_schedule y warehouse_hierarchy
class ScheduleWarehouseHierarchy(BaseModel):
    delivery_schedule_id = ForeignKeyField(DeliverySchedule, on_delete="RESTRICT")
    warehouse_hierarchy_id = ForeignKeyField(WarehouseHierarchy, on_delete="RESTRICT")

    def to_proto(self):
        return DeliveryScheduleWarehouseHierarchyProto(
            id=self.id,
            delivery_schedule_id=self.delivery_schedule_id.id,
            warehouse_hierarchy_id=self.warehouse_hierarchy_id.id,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )

    class Meta:
        table_name = "delivery_schedule_warehouse_hierarchy"


DeferredThroughModel.set_model(DeliverySchedule.transfer_warehouse_ids, ScheduleWarehouseHierarchy)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/schedule_work_schedule_work_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/v1/rules/schedule_work_schedule_work_line.proto\x12:pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line\x1a\x11\x63ommon/base.proto"\xb4\x01\n\x1cScheduleWorkScheduleWorkLine\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x18\n\x10schedule_work_id\x18\x02 \x01(\x05\x12\x1d\n\x15schedule_work_line_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9c\x01\n)ScheduleWorkScheduleWorkLineCreateRequest\x12\x18\n\x10schedule_work_id\x18\x01 \x01(\x05\x12\x1d\n\x15schedule_work_line_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfc\x01\n*ScheduleWorkScheduleWorkLineCreateResponse\x12\x82\x01\n schedule_work_schedule_work_line\x18\x01 \x01(\x0b\x32X.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x85\x03\n\'ScheduleWorkScheduleWorkLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x02\n(ScheduleWorkScheduleWorkLineReadResponse\x12\x82\x01\n schedule_work_schedule_work_line\x18\x01 \x03(\x0b\x32X.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLine\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe8\x01\n)ScheduleWorkScheduleWorkLineUpdateRequest\x12\x82\x01\n schedule_work_schedule_work_line\x18\x01 \x01(\x0b\x32X.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfc\x01\n*ScheduleWorkScheduleWorkLineUpdateResponse\x12\x82\x01\n schedule_work_schedule_work_line\x18\x01 \x01(\x0b\x32X.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"o\n)ScheduleWorkScheduleWorkLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"w\n*ScheduleWorkScheduleWorkLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xff\x07\n#ScheduleWorkScheduleWorkLineService\x12\xf5\x01\n"ScheduleWorkScheduleWorkLineCreate\x12\x65.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineCreateRequest\x1a\x66.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineCreateResponse"\x00\x12\xef\x01\n ScheduleWorkScheduleWorkLineRead\x12\x63.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineReadRequest\x1a\x64.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineReadResponse"\x00\x12\xf5\x01\n"ScheduleWorkScheduleWorkLineUpdate\x12\x65.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineUpdateRequest\x1a\x66.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineUpdateResponse"\x00\x12\xf5\x01\n"ScheduleWorkScheduleWorkLineDelete\x12\x65.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineDeleteRequest\x1a\x66.pro.omni.oms.api.v1.rules.schedule_work_schedule_work_line.ScheduleWorkScheduleWorkLineDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.schedule_work_schedule_work_line_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SCHEDULEWORKSCHEDULEWORKLINE"]._serialized_start = 131
    _globals["_SCHEDULEWORKSCHEDULEWORKLINE"]._serialized_end = 311
    _globals["_SCHEDULEWORKSCHEDULEWORKLINECREATEREQUEST"]._serialized_start = 314
    _globals["_SCHEDULEWORKSCHEDULEWORKLINECREATEREQUEST"]._serialized_end = 470
    _globals["_SCHEDULEWORKSCHEDULEWORKLINECREATERESPONSE"]._serialized_start = 473
    _globals["_SCHEDULEWORKSCHEDULEWORKLINECREATERESPONSE"]._serialized_end = 725
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEREADREQUEST"]._serialized_start = 728
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEREADREQUEST"]._serialized_end = 1117
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEREADRESPONSE"]._serialized_start = 1120
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEREADRESPONSE"]._serialized_end = 1429
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEUPDATEREQUEST"]._serialized_start = 1432
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEUPDATEREQUEST"]._serialized_end = 1664
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEUPDATERESPONSE"]._serialized_start = 1667
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEUPDATERESPONSE"]._serialized_end = 1919
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEDELETEREQUEST"]._serialized_start = 1921
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEDELETEREQUEST"]._serialized_end = 2032
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEDELETERESPONSE"]._serialized_start = 2034
    _globals["_SCHEDULEWORKSCHEDULEWORKLINEDELETERESPONSE"]._serialized_end = 2153
    _globals["_SCHEDULEWORKSCHEDULEWORKLINESERVICE"]._serialized_start = 2156
    _globals["_SCHEDULEWORKSCHEDULEWORKLINESERVICE"]._serialized_end = 3179
# @@protoc_insertion_point(module_scope)



from peewee import CharField

from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.stock.picking_pb2 import Attachment as AttachmentProto


class Attachment(BaseModel):
    doc_id = CharField()
    name = CharField()
    type = CharField()

    class Meta:
        table_name = "attachment"

    def to_proto(self) -> AttachmentProto:
        return AttachmentProto(
            id=self.id,
            doc_id=self.doc_id,
            name=self.name,
            type=self.type,
            object_audit=self.get_audit_proto(),
            active=self.active,
        )



from omni.pro.models.base import BaseModel
from omni.pro.models.sql.rules.delivery_category import DeliveryCategory
from omni.pro.models.sql.rules.delivery_locality import DeliveryLocality
from omni.pro.models.sql.rules.delivery_method_warehouse import DeliveryMethodWarehouse
from omni.pro.models.sql.rules.delivery_schedule import DeliverySchedule
from omni.pro.models.stock.location import Location
from omni.pro.models.stock.warehouse import Warehouse
from omni.pro.protos.v1.rules.delivery_method_pb2 import DeliveryMethod as DeliveryMethodProto
from peewee import CharField, DeferredThroughModel, FloatField, ForeignKeyField, ManyToManyField


class DeliveryMethod(BaseModel):
    TYPE_PICKING_TRANSFER = (
        (0, "PARTIAL"),
        (1, "CONSOLIDATED"),
    )
    VALIDATED_PICKING_CODE = (
        (0, "OPTIONAL"),
        (1, "REQUIRED"),
        (2, "UNNECESSARY"),
    )
    TYPE_DELIVERY = (
        (0, "STORE"),
        (1, "SHIPPING"),
    )
    name = CharField()
    type_picking_transfer = CharField(choices=TYPE_PICKING_TRANSFER)
    validate_warehouse_code = CharField(choices=VALIDATED_PICKING_CODE)
    quantity_security = FloatField()
    code = CharField()
    type_delivery = CharField(choices=TYPE_DELIVERY)
    delivery_location_id = ForeignKeyField(Location, on_delete="RESTRICT")
    transfer_template_id = ForeignKeyField(DeliveryMethodWarehouse, on_delete="RESTRICT")
    category_template_id = ForeignKeyField(DeliveryCategory, on_delete="RESTRICT")
    local_available_id = ForeignKeyField(DeliveryLocality, on_delete="RESTRICT")
    schedule_template_id = ForeignKeyField(DeliverySchedule, on_delete="RESTRICT")
    delivery_warehouse_ids = ManyToManyField(
        Warehouse, backref="delivery_warehouse_ids", through_model=DeferredThroughModel()
    )

    class Meta:
        table_name = "delivery_method"

    def to_proto(self):
        return DeliveryMethodProto(
            id=self.id,
            name=self.name,
            type_picking_transfer=self.type_picking_transfer,
            validate_warehouse_code=self.validate_warehouse_code,
            quantity_security=self.quantity_security,
            code=self.code,
            type_delivery=self.type_delivery,
            delivery_location_id=self.delivery_location_id.id,
            transfer_template_id=self.transfer_template_id.id,
            category_template_id=self.category_template_id.id,
            locality_available_id=self.locality_available_id.id,
            schedule_template_id=self.schedule_template_id.id,
            delivery_warehouse_ids=[warehouse.id for warehouse in self.delivery_warehouse_ids],
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from omni.pro.models.base import BaseModel
from omni.pro.models.stock.location import Location
from omni.pro.models.stock.warehouse import Warehouse
from omni.pro.protos.v1.rules.warehouse_hierarchy_pb2 import WarehouseHierarchy as WarehouseHierarchyProto
from peewee import BooleanField, CharField, FloatField, ForeignKeyField, IntegerField


class WarehouseHierarchy(BaseModel):
    warehouse_id = ForeignKeyField(Warehouse, on_delete="RESTRICT")
    location_id = ForeignKeyField(Location, on_delete="RESTRICT")
    quantity_security = FloatField()
    code = CharField()
    sequence = IntegerField()
    sequence_order = BooleanField()

    class Meta:
        table_name = "warehouse_hierarchy"

    def to_proto(self):
        return WarehouseHierarchyProto(
            id=self.id,
            warehouse_id=self.warehouse_id.id,
            location_id=self.location_id.id,
            quantity_security=self.quantity_security,
            code=self.code,
            sequence=self.sequence,
            sequence_order=self.sequence_order,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from omni.pro.models.base import BaseModel
from omni.pro.models.sql.rules.warehouse_hierarchy import WarehouseHierarchy
from omni.pro.protos.v1.rules.delivery_method_warehouse_pb2 import (
    DeliveryMethodWarehouse as DeliveryMethodWarehouseProto,
)
from peewee import CharField, DeferredThroughModel, ManyToManyField


class DeliveryMethodWarehouse(BaseModel):
    HIERARCHY_WAREHOUSE_SORT = (
        ("0", "asc"),
        ("1", "desc"),
    )
    name = CharField()
    hierarchy_warehouse_sort = CharField(choices=HIERARCHY_WAREHOUSE_SORT)
    transfer_warehouse_ids = ManyToManyField(
        WarehouseHierarchy, backref="transfer_warehouse_ids", through_model=DeferredThroughModel()
    )

    class Meta:
        table_name = "delivery_method_warehouse"

    def to_proto(self):
        return DeliveryMethodWarehouseProto(
            id=self.id,
            name=self.name,
            hierarchy_warehouse_sort=self.hierarchy_warehouse_sort,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_warehouse_ref.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%v1/rules/delivery_warehouse_ref.proto\x12\x33pro.omni.oms.api.v1.rules.delivery_method_warehouse\x1a\x11\x63ommon/base.proto"\xa5\x01\n\x14\x44\x65liveryWarehouseRef\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x8d\x01\n!DeliveryWarehouseRefCreateRequest\x12\x1a\n\x12\x64\x65livery_method_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n"DeliveryWarehouseRefCreateResponse\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfd\x02\n\x1f\x44\x65liveryWarehouseRefReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x02\n DeliveryWarehouseRefReadResponse\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x03(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc9\x01\n!DeliveryWarehouseRefUpdateRequest\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n"DeliveryWarehouseRefUpdateResponse\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"g\n!DeliveryWarehouseRefDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"o\n"DeliveryWarehouseRefDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xdf\x06\n\x1b\x44\x65liveryWarehouseRefService\x12\xcf\x01\n\x1a\x44\x65liveryWarehouseRefCreate\x12V.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefCreateRequest\x1aW.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefCreateResponse"\x00\x12\xc9\x01\n\x18\x44\x65liveryWarehouseRefRead\x12T.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefReadRequest\x1aU.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefReadResponse"\x00\x12\xcf\x01\n\x1a\x44\x65liveryWarehouseRefUpdate\x12V.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefUpdateRequest\x1aW.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefUpdateResponse"\x00\x12\xcf\x01\n\x1a\x44\x65liveryWarehouseRefDelete\x12V.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefDeleteRequest\x1aW.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_warehouse_ref_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYWAREHOUSEREF"]._serialized_start = 114
    _globals["_DELIVERYWAREHOUSEREF"]._serialized_end = 279
    _globals["_DELIVERYWAREHOUSEREFCREATEREQUEST"]._serialized_start = 282
    _globals["_DELIVERYWAREHOUSEREFCREATEREQUEST"]._serialized_end = 423
    _globals["_DELIVERYWAREHOUSEREFCREATERESPONSE"]._serialized_start = 426
    _globals["_DELIVERYWAREHOUSEREFCREATERESPONSE"]._serialized_end = 647
    _globals["_DELIVERYWAREHOUSEREFREADREQUEST"]._serialized_start = 650
    _globals["_DELIVERYWAREHOUSEREFREADREQUEST"]._serialized_end = 1031
    _globals["_DELIVERYWAREHOUSEREFREADRESPONSE"]._serialized_start = 1034
    _globals["_DELIVERYWAREHOUSEREFREADRESPONSE"]._serialized_end = 1312
    _globals["_DELIVERYWAREHOUSEREFUPDATEREQUEST"]._serialized_start = 1315
    _globals["_DELIVERYWAREHOUSEREFUPDATEREQUEST"]._serialized_end = 1516
    _globals["_DELIVERYWAREHOUSEREFUPDATERESPONSE"]._serialized_start = 1519
    _globals["_DELIVERYWAREHOUSEREFUPDATERESPONSE"]._serialized_end = 1740
    _globals["_DELIVERYWAREHOUSEREFDELETEREQUEST"]._serialized_start = 1742
    _globals["_DELIVERYWAREHOUSEREFDELETEREQUEST"]._serialized_end = 1845
    _globals["_DELIVERYWAREHOUSEREFDELETERESPONSE"]._serialized_start = 1847
    _globals["_DELIVERYWAREHOUSEREFDELETERESPONSE"]._serialized_end = 1958
    _globals["_DELIVERYWAREHOUSEREFSERVICE"]._serialized_start = 1961
    _globals["_DELIVERYWAREHOUSEREFSERVICE"]._serialized_end = 2824
# @@protoc_insertion_point(module_scope)



from omni.pro.models.base import BaseModel
from omni.pro.models.sql.rules.calendar import Calendar
from omni.pro.models.sql.rules.schedule_work_line import ScheduleWorkLine
from omni.pro.protos.v1.rules.schedule_work_pb2 import ScheduleWork as ScheduleWorkProto
from omni.pro.protos.v1.rules.schedule_work_schedule_work_line_pb2 import (
    ScheduleWorkScheduleWorkLine as ScheduleWorkScheduleWorkLineProto,
)
from peewee import CharField, DeferredThroughModel, ForeignKeyField, ManyToManyField


class ScheduleWork(BaseModel):
    name = CharField()
    calendar_id = ForeignKeyField(Calendar, on_delete="RESTRICT")
    schedule_work_lines_ids = ManyToManyField(
        ScheduleWorkLine, backref="schedule_work_lines_ids", through_model=DeferredThroughModel()
    )

    class Meta:
        table_name = "schedule_work"

    def to_proto(self):
        return ScheduleWorkProto(
            id=self.id,
            name=self.name,
            calendar_id=self.calendar_id.id,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from omni.pro.models.base import BaseModel
from peewee import CharField, IntegerField


class Category(BaseModel):
    name = CharField()
    code = CharField()
    category_doc_id = CharField()

    class Meta:
        table_name = "category"



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_warehouse_ref_pb2 as v1_dot_rules_dot_delivery__warehouse__ref__pb2


class DeliveryWarehouseRefServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryWarehouseRefCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefCreate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateResponse.FromString,
        )
        self.DeliveryWarehouseRefRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefRead",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadResponse.FromString,
        )
        self.DeliveryWarehouseRefUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefUpdate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateResponse.FromString,
        )
        self.DeliveryWarehouseRefDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefDelete",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteResponse.FromString,
        )


class DeliveryWarehouseRefServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryWarehouseRefCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRefRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRefUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRefDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryWarehouseRefServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryWarehouseRefCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefCreate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateResponse.SerializeToString,
        ),
        "DeliveryWarehouseRefRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefRead,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadResponse.SerializeToString,
        ),
        "DeliveryWarehouseRefUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateResponse.SerializeToString,
        ),
        "DeliveryWarehouseRefDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefDelete,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryWarehouseRefService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryWarehouseRefCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefCreate",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRefRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefRead",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRefUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefUpdate",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRefDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefDelete",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



import grpc
from peewee import CharField

from omni.pro.config import Config
from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.stock.picking_pb2 import User as UserProto
from omni.pro.protos.v1.users import user_pb2, user_pb2_grpc


class User(BaseModel):
    user_doc_id = CharField(unique=True)
    name = CharField()

    class Meta:
        table_name = "user"

    def to_proto(self):
        return UserProto(
            id=self.id,
            user_doc_id=self.user_doc_id,
            name=self.name,
            object_audit=self.get_audit_proto(),
            active=self.active,
        )

    def get_document_info(self, *args, **kwargs):
        with grpc.insecure_channel(f"{Config.USER_MS_HOST}:{Config.USER_MS_PORT}") as channel:
            stub = user_pb2_grpc.UsersServiceStub(channel)
            response = stub.UserRead(user_pb2.UserReadRequest(id=self.user_doc_id, **kwargs))
            return response.users[0] if response.users else None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/warehouse_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/warehouse_delivery_method.proto\x12\x33pro.omni.oms.api.v1.rules.warehouse_delivery_method\x1a\x11\x63ommon/base.proto"\xa8\x01\n\x17WarehouseDeliveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x90\x01\n$WarehouseDeliveryMethodCreateRequest\x12\x14\n\x0cwarehouse_id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%WarehouseDeliveryMethodCreateResponse\x12o\n\x19warehouse_delivery_method\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x80\x03\n"WarehouseDeliveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9c\x02\n#WarehouseDeliveryMethodReadResponse\x12o\n\x19warehouse_delivery_method\x18\x01 \x03(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xcf\x01\n$WarehouseDeliveryMethodUpdateRequest\x12o\n\x19warehouse_delivery_method\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%WarehouseDeliveryMethodUpdateResponse\x12o\n\x19warehouse_delivery_method\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"j\n$WarehouseDeliveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"r\n%WarehouseDeliveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x86\x07\n\x1eWarehouseDeliveryMethodService\x12\xd8\x01\n\x1dWarehouseDeliveryMethodCreate\x12Y.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodCreateRequest\x1aZ.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodCreateResponse"\x00\x12\xd2\x01\n\x1bWarehouseDeliveryMethodRead\x12W.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodReadRequest\x1aX.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodReadResponse"\x00\x12\xd8\x01\n\x1dWarehouseDeliveryMethodUpdate\x12Y.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodUpdateRequest\x1aZ.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodUpdateResponse"\x00\x12\xd8\x01\n\x1dWarehouseDeliveryMethodDelete\x12Y.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodDeleteRequest\x1aZ.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.warehouse_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSEDELIVERYMETHOD"]._serialized_start = 117
    _globals["_WAREHOUSEDELIVERYMETHOD"]._serialized_end = 285
    _globals["_WAREHOUSEDELIVERYMETHODCREATEREQUEST"]._serialized_start = 288
    _globals["_WAREHOUSEDELIVERYMETHODCREATEREQUEST"]._serialized_end = 432
    _globals["_WAREHOUSEDELIVERYMETHODCREATERESPONSE"]._serialized_start = 435
    _globals["_WAREHOUSEDELIVERYMETHODCREATERESPONSE"]._serialized_end = 662
    _globals["_WAREHOUSEDELIVERYMETHODREADREQUEST"]._serialized_start = 665
    _globals["_WAREHOUSEDELIVERYMETHODREADREQUEST"]._serialized_end = 1049
    _globals["_WAREHOUSEDELIVERYMETHODREADRESPONSE"]._serialized_start = 1052
    _globals["_WAREHOUSEDELIVERYMETHODREADRESPONSE"]._serialized_end = 1336
    _globals["_WAREHOUSEDELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1339
    _globals["_WAREHOUSEDELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1546
    _globals["_WAREHOUSEDELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1549
    _globals["_WAREHOUSEDELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1776
    _globals["_WAREHOUSEDELIVERYMETHODDELETEREQUEST"]._serialized_start = 1778
    _globals["_WAREHOUSEDELIVERYMETHODDELETEREQUEST"]._serialized_end = 1884
    _globals["_WAREHOUSEDELIVERYMETHODDELETERESPONSE"]._serialized_start = 1886
    _globals["_WAREHOUSEDELIVERYMETHODDELETERESPONSE"]._serialized_end = 2000
    _globals["_WAREHOUSEDELIVERYMETHODSERVICE"]._serialized_start = 2003
    _globals["_WAREHOUSEDELIVERYMETHODSERVICE"]._serialized_end = 2905
# @@protoc_insertion_point(module_scope)



from omni.pro.models.base import BaseModel
from peewee import CharField, IntegerField


class TerritoryMatrix(BaseModel):
    name = CharField()
    code = CharField()
    sequnce = IntegerField()

    class Meta:
        table_name = "territory_matrix"



from omni.pro.models.base import BaseModel
from peewee import CharField, ForeignKeyField, IntegerField


class TerritoryMatrixValues(BaseModel):
    name = CharField()
    code = CharField()
    values = ForeignKeyField("self", backref="child_values", null=True)

    class Meta:
        table_name = "territory_matrix_values"



from peewee import CharField

from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.stock.stock_pb2 import Product as ProductProto


class Product(BaseModel):
    product_doc_id = CharField()
    template_doc_id = CharField()
    name = CharField()

    class Meta:
        table_name = "product"

    def to_proto(self) -> ProductProto:
        return ProductProto(
            id=self.id,
            product_doc_id=self.product_doc_id,
            template_doc_id=self.template_doc_id,
            name=self.name,
            object_audit=self.get_audit_proto(),
            active=self.active,
        )



from omni.pro.models.base import BaseModel

# from omni.pro.models.sql.rules.delivery_locality_territory_matrix_values import DeliveryLocalityTerritoryMatrixValues
from omni.pro.models.sql.utilities.country import Country
from omni.pro.models.sql.utilities.territory_matrix import TerritoryMatrix
from omni.pro.models.sql.utilities.territory_matrix_values import TerritoryMatrixValues
from omni.pro.protos.v1.rules.delivery_locality_pb2 import DeliveryLocality as DeliveryLocalityProto
from peewee import CharField, DeferredThroughModel, ForeignKeyField, ManyToManyField


class DeliveryLocality(BaseModel):
    name = CharField()
    country_id = ForeignKeyField(Country, on_delete="RESTRICT")
    territory_matrix_id = ForeignKeyField(TerritoryMatrix, on_delete="RESTRICT")
    territory_matrix_values_ids = ManyToManyField(
        TerritoryMatrixValues,
        backref="territory_matrix_values_ids",
        through_model=DeferredThroughModel(),
    )

    class Meta:
        table_name = "delivery_locality"

    def to_proto(self):
        return DeliveryLocalityProto(
            id=self.id,
            name=self.name,
            country_id=self.country_id.id,
            territory_matrix_id=self.territory_matrix_id.id,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from datetime import datetime

from google.protobuf.timestamp_pb2 import Timestamp
from mongoengine import BooleanField, DateTimeField, Document, EmbeddedDocument, EmbeddedDocumentField, StringField
from omni.pro.protos.common.base_pb2 import Context as ContextProto
from omni.pro.protos.common.base_pb2 import Object as ObjectProto
from omni.pro.protos.common.base_pb2 import ObjectAudit as AuditProto
from peewee import BooleanField as BooleanFieldPeewee
from peewee import CharField as CharFieldPeewee
from peewee import DateTimeField as DateTimeFieldPeewee
from peewee import IntegerField as IntegerFieldPeewee
from peewee import Model


class BaseEmbeddedDocument(EmbeddedDocument):
    meta = {
        "abstract": True,
        "strict": False,
    }

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError


class BaseObjectEmbeddedDocument(BaseEmbeddedDocument):
    code = StringField()
    code_name = StringField()
    meta = {
        "allow_inheritance": True,
    }

    def to_proto(self):
        return ObjectProto(
            code=self.code,
            code_name=self.code_name,
        )


class Audit(BaseEmbeddedDocument):
    created_at = DateTimeField(default=datetime.utcnow)
    created_by = StringField()
    updated_at = DateTimeField()
    updated_by = StringField()
    deleted_at = DateTimeField()
    deleted_by = StringField()

    def to_proto(self):
        create_at_ts = Timestamp()
        create_at_ts.FromDatetime(self.created_at)
        update_at_ts = Timestamp()
        update_at_ts.FromDatetime(self.updated_at)
        return AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            created_at=create_at_ts,
            updated_at=update_at_ts,
        )


class Context(BaseEmbeddedDocument):
    tenant = StringField()
    user = StringField()

    def to_proto(self):
        return ContextProto(
            tenant=self.tenant,
            user=self.user,
        )


class BaseDocument(Document):
    context = EmbeddedDocumentField(Context)
    audit = EmbeddedDocumentField(Audit)
    active = BooleanField(default=True)

    meta = {
        "abstract": True,
        "strict": False,
    }

    def save(self, *args, **kwargs):
        if not self.context:
            self.context = Context()
        if not self.audit:
            self.audit = Audit(created_by=self.context.user)
        self.audit.updated_by = self.context.user
        self.audit.updated_at = datetime.utcnow()
        return super().save(*args, **kwargs)

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError

    @classmethod
    def reference_list(cls):
        return [cls]


class BaseAuditEmbeddedDocument(BaseEmbeddedDocument):
    context = EmbeddedDocumentField(Context)
    audit = EmbeddedDocumentField(Audit)
    active = BooleanField(default=True)
    meta = {
        "abstract": True,
        "strict": False,
    }

    # TODO: Add a method to update the audit fields
    def save(self, *args, **kwargs):
        if not self.context:
            self.context = Context()
        if not self.audit:
            self.audit = Audit(created_by=self.context.user)
        self.audit.updated_by = self.context.user
        self.audit.updated_at = datetime.utcnow()
        return super().save(*args, **kwargs)


BaseAuditContextEmbeddedDocument = BaseAuditEmbeddedDocument


class AuditPeewee(Model):
    created_by = IntegerFieldPeewee(null=True, default=None)
    updated_by = IntegerFieldPeewee(null=True, default=None)
    deleted_by = IntegerFieldPeewee(null=True, default=None)
    created_at = DateTimeFieldPeewee(null=True, default=None)
    updated_at = DateTimeFieldPeewee(null=True, default=None)
    deleted_at = DateTimeFieldPeewee(null=True, default=None)

    def to_proto(self) -> AuditProto:
        return AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            deleted_by=self.deleted_by,
            created_at=self.created_at,
            updated_at=self.updated_at,
            deleted_at=self.deleted_at,
        )


class ContextPeewee(Model):
    tenant = CharFieldPeewee()
    user = CharFieldPeewee()

    def to_proto(self) -> ContextProto:
        return ContextProto(
            tenant=self.tenant,
            user=self.user,
        )


class BaseModel(Model):
    created_by = CharFieldPeewee(null=True, default=None)
    updated_by = CharFieldPeewee(null=True, default=None)
    deleted_by = CharFieldPeewee(null=True, default=None)
    created_at = DateTimeFieldPeewee(default=datetime.now())
    updated_at = DateTimeFieldPeewee(null=True, default=None)
    deleted_at = DateTimeFieldPeewee(null=True, default=None)
    active = BooleanFieldPeewee(null=False, default=True)

    class Meta:
        abstract = True
        database = None

    def get_audit_proto(self) -> AuditProto:
        created_at_ts = Timestamp()
        created_at_ts.FromDatetime(self.created_at)
        updated_at_ts = Timestamp()
        updated_at_ts.FromDatetime(self.updated_at)
        audit_proto = AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            deleted_by=self.deleted_by,
            created_at=created_at_ts,
            updated_at=updated_at_ts,
        )
        if self.deleted_at:
            deleted_at_ts = Timestamp()
            deleted_at_ts.FromDatetime(self.deleted_at)
            audit_proto.deleted_at = deleted_at_ts
        return audit_proto

    def get_context_proto(self) -> ContextProto:
        return ContextProto(
            tenant=self.context["tenant"],
            user=self.context["user"],
        )

    # TODO add a method to update the audit fields in update and delete
    def save(self, *args, **kwargs):
        if self.created_by is None:
            self.created_by = self.context["user"]
        if self.created_at is None:
            self.created_at = datetime.now()
        self.updated_by = self.context["user"]
        self.updated_at = datetime.now()
        return super().save(*args, **kwargs)

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError

    def sync_data(self, *args, **kwargs):
        raise NotImplementedError

    def get_document_info(self, *args, **kwargs):
        raise NotImplementedError



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_category_category.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)v1/rules/delivery_category_category.proto\x12\x34pro.omni.oms.api.v1.rules.delivery_category_category\x1a\x11\x63ommon/base.proto"\xaa\x01\n\x18\x44\x65liveryCategoryCategory\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\x14\x64\x65livery_category_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n%DeliveryCategoryCategoryCreateRequest\x12\x1c\n\x14\x64\x65livery_category_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryCategoryCategoryCreateResponse\x12r\n\x1a\x64\x65livery_category_category\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x81\x03\n#DeliveryCategoryCategoryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa2\x02\n$DeliveryCategoryCategoryReadResponse\x12t\n\x1c\x64\x65livery_category_categories\x18\x01 \x03(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xd3\x01\n%DeliveryCategoryCategoryUpdateRequest\x12r\n\x1a\x64\x65livery_category_category\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryCategoryCategoryUpdateResponse\x12r\n\x1a\x64\x65livery_category_category\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"k\n%DeliveryCategoryCategoryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"s\n&DeliveryCategoryCategoryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9b\x07\n\x1f\x44\x65liveryCategoryCategoryService\x12\xdd\x01\n\x1e\x44\x65liveryCategoryCategoryCreate\x12[.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryCreateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryCreateResponse"\x00\x12\xd7\x01\n\x1c\x44\x65liveryCategoryCategoryRead\x12Y.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryReadRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryReadResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryCategoryCategoryUpdate\x12[.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryUpdateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryUpdateResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryCategoryCategoryDelete\x12[.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryDeleteRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_category_category_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYCATEGORYCATEGORY"]._serialized_start = 119
    _globals["_DELIVERYCATEGORYCATEGORY"]._serialized_end = 289
    _globals["_DELIVERYCATEGORYCATEGORYCREATEREQUEST"]._serialized_start = 292
    _globals["_DELIVERYCATEGORYCATEGORYCREATEREQUEST"]._serialized_end = 438
    _globals["_DELIVERYCATEGORYCATEGORYCREATERESPONSE"]._serialized_start = 441
    _globals["_DELIVERYCATEGORYCATEGORYCREATERESPONSE"]._serialized_end = 672
    _globals["_DELIVERYCATEGORYCATEGORYREADREQUEST"]._serialized_start = 675
    _globals["_DELIVERYCATEGORYCATEGORYREADREQUEST"]._serialized_end = 1060
    _globals["_DELIVERYCATEGORYCATEGORYREADRESPONSE"]._serialized_start = 1063
    _globals["_DELIVERYCATEGORYCATEGORYREADRESPONSE"]._serialized_end = 1353
    _globals["_DELIVERYCATEGORYCATEGORYUPDATEREQUEST"]._serialized_start = 1356
    _globals["_DELIVERYCATEGORYCATEGORYUPDATEREQUEST"]._serialized_end = 1567
    _globals["_DELIVERYCATEGORYCATEGORYUPDATERESPONSE"]._serialized_start = 1570
    _globals["_DELIVERYCATEGORYCATEGORYUPDATERESPONSE"]._serialized_end = 1801
    _globals["_DELIVERYCATEGORYCATEGORYDELETEREQUEST"]._serialized_start = 1803
    _globals["_DELIVERYCATEGORYCATEGORYDELETEREQUEST"]._serialized_end = 1910
    _globals["_DELIVERYCATEGORYCATEGORYDELETERESPONSE"]._serialized_start = 1912
    _globals["_DELIVERYCATEGORYCATEGORYDELETERESPONSE"]._serialized_end = 2027
    _globals["_DELIVERYCATEGORYCATEGORYSERVICE"]._serialized_start = 2030
    _globals["_DELIVERYCATEGORYCATEGORYSERVICE"]._serialized_end = 2953
# @@protoc_insertion_point(module_scope)



from mongoengine import BooleanField, EmbeddedDocumentField, FloatField, IntField, ListField, MapField, StringField
from omni.pro.models.base import Audit, BaseAuditEmbeddedDocument, BaseDocument, BaseEmbeddedDocument
from omni.pro.protos.common.base_pb2 import Object as CurrencyProto
from omni.pro.protos.v1.utilities.country_pb2 import Country as CountryProto
from omni.pro.protos.v1.utilities.document_type_pb2 import DocumentType as DocumentTypeProto
from omni.pro.protos.v1.utilities.language_pb2 import Language as LanguageProto
from omni.pro.protos.v1.utilities.payment_method_pb2 import PaymentMethod as PaymentMethodProto
from omni.pro.protos.v1.utilities.tax_pb2 import Tax as TaxProto
from omni.pro.protos.v1.utilities.territory_matrix_pb2 import TerritoryMatrix as TerritoryMatrixProto
from omni.pro.protos.v1.utilities.timezone_pb2 import Timezone as TimezoneProto


class Timezone(BaseAuditEmbeddedDocument):
    name = StringField()
    code = StringField()
    utc_offset = StringField()
    active = BooleanField(default=True)

    def to_proto(self) -> TimezoneProto:
        return TimezoneProto(
            name=self.name,
            code=self.code,
            utc_offset=self.utc_offset,
            active=self.active,
            object_audit=self.audit.to_proto(),
        )


class Language(BaseAuditEmbeddedDocument):
    name = StringField()
    code = StringField()
    active = BooleanField(default=True)

    def to_proto(self) -> LanguageProto:
        return LanguageProto(
            name=self.name,
            code=self.code,
            active=self.active,
            object_audit=self.audit.to_proto(),
        )


class Currency(BaseAuditEmbeddedDocument):
    name = StringField()
    code = StringField()
    currency_unit_label = StringField()
    currency_subunit_label = StringField()
    rate = IntField()
    rounding = FloatField()
    decimal_places = IntField()
    symbol = StringField()
    position = StringField()

    def to_proto(self) -> CurrencyProto:
        return CurrencyProto(
            name=self.name,
            code=self.code,
            currency_unit_label=self.currency_unit_label,
            currency_subunit_label=self.currency_subunit_label,
            rate=self.rate,
            rounding=self.rounding,
            decimal_places=self.decimal_places,
            symbol=self.symbol,
            position=self.position,
            active=self.active,
            # object_audit=self.audit.to_proto(),
        )


class Tax(BaseAuditEmbeddedDocument):
    name = StringField()
    code = StringField()
    rate = FloatField()
    rounding = FloatField()
    decimal_places = IntField()
    position = StringField()

    def to_proto(self) -> TaxProto:
        if not self.audit:
            self.audit = Audit()
        return TaxProto(
            name=self.name,
            code=self.code,
            rate=self.rate,
            rounding=self.rounding,
            decimal_places=self.decimal_places,
            position=self.position,
            active=self.active,
            # object_audit=self.audit.to_proto(),
        )


class DocumentType(BaseAuditEmbeddedDocument):
    name = StringField()
    code = StringField()
    size = IntField()

    def to_proto(self) -> DocumentTypeProto:
        return DocumentTypeProto(
            name=self.name,
            code=self.code,
            size=self.size,
            active=self.active,
            # object_audit=self.audit.to_proto(),
        )


class PaymentMethod(BaseAuditEmbeddedDocument):
    name = StringField()
    code = StringField()
    description = StringField()

    def to_proto(self) -> PaymentMethodProto:
        return PaymentMethodProto(
            name=self.name,
            code=self.code,
            description=self.description,
            active=self.active,
            # object_audit=self.audit.to_proto(),
        )


class TerritoryMatrix(BaseAuditEmbeddedDocument):
    sequence = IntField()
    name = StringField()
    code = StringField()

    def to_proto(self) -> TerritoryMatrixProto:
        return TerritoryMatrixProto(
            sequence=self.sequence,
            name=self.name,
            code=self.code,
            active=self.active,
            # object_audit=self.audit.to_proto(),
        )


class Country(BaseDocument):
    code = StringField()
    name = StringField()
    phone_number_size = IntField()
    phone_prefix = StringField()
    require_zipcode = BooleanField()
    currency = EmbeddedDocumentField(Currency)
    taxes = ListField(EmbeddedDocumentField(Tax))
    document_types = ListField(EmbeddedDocumentField(DocumentType))
    payment_methods = ListField(EmbeddedDocumentField(PaymentMethod))
    territory_matrixes = ListField(EmbeddedDocumentField(TerritoryMatrix))
    low_level = StringField()
    timezones = ListField(EmbeddedDocumentField(Timezone))
    languages = ListField(EmbeddedDocumentField(Language))

    def to_proto(self) -> CountryProto:
        return CountryProto(
            id=str(self.id),
            code=self.code,
            name=self.name,
            phone_number_size=self.phone_number_size,
            phone_prefix=self.phone_prefix,
            require_zipcode=self.require_zipcode,
            currency=self.currency.to_proto() if self.currency else None,
            taxes=[tax.to_proto() for tax in self.taxes],
            document_types=[document_type.to_proto() for document_type in self.document_types],
            payment_methods=[payment_method.to_proto() for payment_method in self.payment_methods],
            territory_matrixes=[territory_matrix.to_proto() for territory_matrix in self.territory_matrixes],
            timezones=[timezone.to_proto() for timezone in self.timezones],
            languages=[language.to_proto() for language in self.languages],
            active=self.active,
            object_audit=self.audit.to_proto(),
        )



from typing import Optional as _Optional

from omni.pro.protos.common import base_pb2
from omni.pro.util import HTTPStatus


class MessageCode(object):
    INTERNAL_SERVER_ERROR = "SV001"
    INPUT_VALIDATOR_ERROR = "SV002"
    COGNITO_CLIENT_ERROR = "CO001"
    USER_PASSWORD_CHANGED = "US007"
    USER_EMAIL_CHANGED = "US008"
    USER_UNAUTHORIZED = "US009"
    RESOURCE_CREATED = "RS001"
    RESOURCE_READ = "RS002"
    RESOURCE_FETCHED = "RS002"
    RESOURCE_UPDATED = "RS003"
    RESOURCE_DELETED = "RS004"
    RESOURCE_NOT_FOUND = "RS005"
    RESOURCE_ALREADY_EXISTS = "RS006"


class MessageResponse(object):
    def __init__(self, cls):
        self.cls = cls

    def response(
        self,
        message: str,
        success: bool,
        status_code: int = HTTPStatus.OK,
        message_code: _Optional[str] = ...,
        **kwargs
    ):
        return self.cls(
            response_standard=base_pb2.ResponseStandard(
                success=success, message=message, status_code=status_code, message_code=message_code
            ),
            **kwargs,
        )

    # FIXME: This is a bad name for this method
    def bad_response(self, message: str, **kwargs):
        return self.input_validator_response(message, **kwargs)

    def input_validator_response(self, message: str, **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.BAD_REQUEST,
            message_code=MessageCode.INPUT_VALIDATOR_ERROR,
            **kwargs,
        )

    def created_response(self, message: str, **kwargs):
        return self.response(
            success=True,
            message=message,
            status_code=HTTPStatus.CREATED,
            message_code=MessageCode.RESOURCE_CREATED,
            **kwargs,
        )

    def deleted_response(self, message: str, **kwargs):
        return self.response(
            success=True,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_DELETED,
            **kwargs,
        )

    def updated_response(self, message: str, **kwargs):
        return self.response(
            success=True,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_UPDATED,
            **kwargs,
        )

    def fetched_response(self, message: str, paginated: base_pb2.Paginated, total: int, count=0, **kwargs):
        if kwargs.pop("id", False) and total == 0:
            return self.not_found_response(message, **kwargs)

        return self.response(
            success=total > 0,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_FETCHED,
            meta_data=base_pb2.MetaData(
                limit=paginated.limit,
                offset=paginated.offset,
                total=total,
                count=count or total,
            ),
            **kwargs,
        )

    def internal_response(self, message: str, message_code: str = MessageCode.INTERNAL_SERVER_ERROR, **kwargs):
        return self.response(
            message=message,
            success=False,
            status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
            message_code=message_code,
            **kwargs,
        )

    def already_exists_response(self, message: str, **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_ALREADY_EXISTS,
            **kwargs,
        )

    def not_found_response(self, message: str, **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.NOT_FOUND,
            message_code=MessageCode.RESOURCE_NOT_FOUND,
            **kwargs,
        )

    def unauthorized_response(self, message: str = "User Unauthorized", **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.UNAUTHORIZED,
            message_code=MessageCode.USER_UNAUTHORIZED,
            **kwargs,
        )



from google.protobuf import json_format


# FIXME: change param including_default_value_fields to default_values when invoking util.MessageToDict
def MessageToDict(message, default_values=False, including_default_value_fields=False, **kwargs):
    """
    Converts protobuf message to a JSON dictionary considering the preserving proto field names.
    @param message: The protobuf message to convert.
    @param default_values: If True, fields with default values will be included in the dictionary.
    @param kwargs: Additional arguments to pass to json_format.MessageToDict.
    @return: The JSON dictionary.
    """
    return json_format.MessageToDict(
        message,
        preserving_proto_field_name=True,
        including_default_value_fields=default_values or including_default_value_fields,
        **kwargs,
    )


def format_request(data, request, proto) -> object:
    return json_format.ParseDict(data, getattr(proto, request)())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/territory_matrix.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#v1/utilities/territory_matrix.proto\x12.pro.omni.oms.api.v1.utilities.territory_matrix\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xcc\x01\n\x0fTerritoryMatrix\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x12\n\ncountry_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc1\x01\n\x19TerritoryMatrixAddRequest\x12\x12\n\ncountry_id\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc4\x01\n\x1aTerritoryMatrixAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12[\n\x12territory_matrixes\x18\x02 \x01(\x0b\x32?.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrix"\xf8\x02\n\x1aTerritoryMatrixReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x80\x02\n\x1bTerritoryMatrixReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12[\n\x12territory_matrixes\x18\x03 \x03(\x0b\x32?.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrix"\xb1\x01\n\x1cTerritoryMatrixUpdateRequest\x12Y\n\x10territory_matrix\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrix\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc7\x01\n\x1dTerritoryMatrixUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12[\n\x12territory_matrixes\x18\x02 \x01(\x0b\x32?.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrix"b\n\x1cTerritoryMatrixDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"j\n\x1dTerritoryMatrixDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xed\x05\n\x16TerritoryMatrixService\x12\xad\x01\n\x12TerritoryMatrixAdd\x12I.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixAddRequest\x1aJ.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixAddResponse"\x00\x12\xb0\x01\n\x13TerritoryMatrixRead\x12J.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixReadRequest\x1aK.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixReadResponse"\x00\x12\xb6\x01\n\x15TerritoryMatrixUpdate\x12L.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixUpdateRequest\x1aM.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixUpdateResponse"\x00\x12\xb6\x01\n\x15TerritoryMatrixDelete\x12L.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixDeleteRequest\x1aM.pro.omni.oms.api.v1.utilities.territory_matrix.TerritoryMatrixDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.territory_matrix_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TERRITORYMATRIX"]._serialized_start = 139
    _globals["_TERRITORYMATRIX"]._serialized_end = 343
    _globals["_TERRITORYMATRIXADDREQUEST"]._serialized_start = 346
    _globals["_TERRITORYMATRIXADDREQUEST"]._serialized_end = 539
    _globals["_TERRITORYMATRIXADDRESPONSE"]._serialized_start = 542
    _globals["_TERRITORYMATRIXADDRESPONSE"]._serialized_end = 738
    _globals["_TERRITORYMATRIXREADREQUEST"]._serialized_start = 741
    _globals["_TERRITORYMATRIXREADREQUEST"]._serialized_end = 1117
    _globals["_TERRITORYMATRIXREADRESPONSE"]._serialized_start = 1120
    _globals["_TERRITORYMATRIXREADRESPONSE"]._serialized_end = 1376
    _globals["_TERRITORYMATRIXUPDATEREQUEST"]._serialized_start = 1379
    _globals["_TERRITORYMATRIXUPDATEREQUEST"]._serialized_end = 1556
    _globals["_TERRITORYMATRIXUPDATERESPONSE"]._serialized_start = 1559
    _globals["_TERRITORYMATRIXUPDATERESPONSE"]._serialized_end = 1758
    _globals["_TERRITORYMATRIXDELETEREQUEST"]._serialized_start = 1760
    _globals["_TERRITORYMATRIXDELETEREQUEST"]._serialized_end = 1858
    _globals["_TERRITORYMATRIXDELETERESPONSE"]._serialized_start = 1860
    _globals["_TERRITORYMATRIXDELETERESPONSE"]._serialized_end = 1966
    _globals["_TERRITORYMATRIXSERVICE"]._serialized_start = 1969
    _globals["_TERRITORYMATRIXSERVICE"]._serialized_end = 2718
# @@protoc_insertion_point(module_scope)



from peewee import CharField

from omni.pro.models.base import BaseModel
from omni.pro.protos.v1.stock.stock_pb2 import Uom as UomProto


class Uom(BaseModel):
    uom_doc_id = CharField()
    code = CharField(unique=True)
    name = CharField()

    class Meta:
        table_name = "uom"

    def to_proto(self) -> UomProto:
        return UomProto(
            id=self.id,
            uom_doc_id=self.uom_doc_id,
            code=self.code,
            name=self.name,
            active=self.active,
            object_audit=self.get_audit_proto(),
        )



from peewee import BooleanField, CharField, ForeignKeyField, IntegerField

from omni.pro.models.base import BaseModel
from omni.pro.models.stock.location import Location
from omni.pro.models.stock.uom import Uom as Uom
from omni.pro.models.stock.warehouse import Warehouse
from omni.pro.protos.v1.stock.stock_pb2 import PickingType as PickingTypeProto


class PickingType(BaseModel):
    name = CharField()
    sequence_code = CharField()
    warehouse_id = ForeignKeyField(Warehouse, backref="picking_types")
    code = CharField(unique=True)
    return_picking_type_id = ForeignKeyField("self", backref="children", null=True)
    show_operations = BooleanField(default=False)
    show_reserved = BooleanField(default=False)
    default_location_src_id = ForeignKeyField(Location)
    default_location_dest_id = ForeignKeyField(Location)
    prefix = CharField()
    padding = IntegerField()
    number_increment = IntegerField()
    number_next_actual = IntegerField()

    class Meta:
        table_name = "picking_type"

    def to_proto(self):
        return_picking_type_id = self.return_picking_type_id.id if self.return_picking_type_id else None
        return PickingTypeProto(
            id=self.id,
            name=self.name,
            sequence_code=self.sequence_code,
            warehouse_id=self.warehouse_id.id,
            code=self.code,
            return_picking_type_id=return_picking_type_id,
            show_operations=self.show_operations,
            show_reserved=self.show_reserved,
            default_location_dest_id=self.default_location_dest_id.id,
            default_location_src_id=self.default_location_src_id.id,
            prefix=self.prefix,
            padding=self.padding,
            number_increment=self.number_increment,
            number_next_actual=self.number_next_actual,
            object_audit=self.get_audit_proto(),
            active=self.active,
        )
